@@ -22,7 +22,6 @@ PScaptureHead <- function(file, charpath, charpos, setflat, encoding,
       # file I run cannot reset my counters with a restore!
       "true setglobal",
       "/convertToR dup 100 dict def load begin",
-      "/str 50 string def",
       "/id 1 def",
       # Do these need to be even "larger"?
       "/xmax -99999 def",
@@ -113,6 +112,8 @@ PScaptureHead <- function(file, charpath, charpos, setflat, encoding,
       
       # path processing
       "/mymove {",
+      "  1 dict begin",
+      "  /str 50 string def",
       "  (\t<move) print",
       "  transform",
       "  dup",
@@ -134,8 +135,11 @@ PScaptureHead <- function(file, charpath, charpos, setflat, encoding,
       "  convertToR /xmax get gt {convertToR /xmax curx put} if",
       "  ( x=') print str cvs print (') print",
       "  (/>\n) print",
+      "  end",
       "} def",
       "/myline {",
+      "  1 dict begin",
+      "  /str 50 string def",
       "  (\t<line) print",
       "  transform",
       "  dup",
@@ -153,20 +157,26 @@ PScaptureHead <- function(file, charpath, charpos, setflat, encoding,
       "  convertToR /xmax get gt {convertToR /xmax curx put} if",
       "  ( x=') print str cvs print (') print",
       "  (/>\n) print",
+      "  end",
       "  } def",
       "/mycurve {",
       "  } def",
       "/myclose {",
+      "  1 dict begin",
+      "  /str 50 string def",
       # Convert 'closepath' to 'lineto'
       # "  (\t<close/>\n) print",
       "  (\t<line) print",
       "  ( y=') print convertToR /ystart get str cvs print (') print",
       "  ( x=') print convertToR /xstart get str cvs print (') print",
       "  (/>\n) print",
+      "  end",
       "  } def",
       
       # echoing graphics state
       "/printcol {",
+      "  1 dict begin",
+      "  /str 50 string def",
       # What colorspace are we in?
       # Return colorspace array and extract
       # first element which is colorspace name
@@ -184,6 +194,7 @@ PScaptureHead <- function(file, charpath, charpos, setflat, encoding,
       "  ( b=') print str cvs print (') print",
       "  (/>\n) print",
       "  pop pop",
+      "  end",
       "  } def",
       "/printlwd {",
       # lwd is in user coords so transform
@@ -213,6 +224,8 @@ PScaptureHead <- function(file, charpath, charpos, setflat, encoding,
       "  ( lty=') print pop {0 transform pop 0 0 transform pop sub str cvs print ( ) print} forall (') print",
       "} def",      
       "/printstyle {",
+      "  1 dict begin",
+      "  /str 50 string def",
       "  (\t\t<style) print",
       "  printlwd",
       "  printdash",
@@ -220,10 +233,13 @@ PScaptureHead <- function(file, charpath, charpos, setflat, encoding,
       "  printlinemiter",
       "  printlinejoin",
       "  (/>\n) print",
+      "  end",
       "} def",
 
       # print out "closestroke" marker plus graphics state info
       "/mystroke {",
+      "  1 dict begin",
+      "  /str 50 string def",
       "  (<path type='stroke') print",
       "  ( id=') print convertToR /id get str cvs print ('>\n) print",
       "  (\t<context>\n) print",
@@ -233,8 +249,11 @@ PScaptureHead <- function(file, charpath, charpos, setflat, encoding,
       "  pathforall",
       "  convertToR /id get 1 add convertToR exch /id exch put",
       "  (</path>\n\n) print",
+      "  end",
       "} def",
       "/myfill {",
+      "  1 dict begin",
+      "  /str 50 string def",
       "  (<path type='fill') print",
       "  ( id=') print convertToR /id get str cvs print ('>\n) print",
       "  (\t<context>\n) print",
@@ -244,8 +263,11 @@ PScaptureHead <- function(file, charpath, charpos, setflat, encoding,
       "  pathforall",
       "  convertToR /id get 1 add convertToR exch /id exch put",
       "  (</path>\n\n) print",
+      "  end",
       "} def",
       "/myeofill {",
+      "  1 dict begin",
+      "  /str 50 string def",
       "  (<path type='eofill') print",
       "  ( id=') print convertToR /id get str cvs print ('>\n) print",
       "  (\t<context>\n) print",
@@ -255,8 +277,11 @@ PScaptureHead <- function(file, charpath, charpos, setflat, encoding,
       "  pathforall",
       "  convertToR /id get 1 add convertToR exch /id exch put",
       "  (</path>\n\n) print",
+      "  end",
       "} def",
       "/mytext {",
+      "  1 dict begin",
+      "  /str 50 string def",
       "  (<text ) print",
       "  ( id=') print convertToR /id get str cvs print (') print",
       "  convertToR /id get 1 add convertToR exch /id exch put",
@@ -354,8 +379,11 @@ PScaptureHead <- function(file, charpath, charpos, setflat, encoding,
       },
       
       "  (</text>\n\n) print",
+      "  end",
       "} def",
       "/mychar {",
+      "  1 dict begin",
+      "  /str 50 string def",
       "  (<path type='char') print",
       "  ( id=') print convertToR /id get str cvs print (') print",
       # Insert MARKS here so that postProcess() can easily locate strings
@@ -367,6 +395,7 @@ PScaptureHead <- function(file, charpath, charpos, setflat, encoding,
       "  (\t</context>\n\n) print",
       "  convertToR /id get 1 add convertToR exch /id exch put",
       "  (</path>\n\n) print",
+      "  end",
       "} def",
 
       "/checkskew {",
@@ -1003,6 +1032,8 @@ PScaptureFoot <-
       # that we just ran does something nasty like clearing the dict stack!
       "convertToR begin",
       # XML file footer info
+      "1 dict begin",
+      "/str 50 string def",
       "(<summary count=') print convertToR /id get 1 sub str cvs print (') print",
       "( ymax=') print convertToR /ymax get str cvs print (') print",
       "( ymin=') print convertToR /ymin get str cvs print (') print",
@@ -1010,6 +1041,7 @@ PScaptureFoot <-
       "( xmin=') print convertToR /xmin get str cvs print (') print",
       "(/>\n\n) print",
       "(</picture>\n) print",
+      "end",
 
       # EOF
       "%% EOF\n"
